@@ -21,17 +21,20 @@
 import os
 from datetime import datetime
 from logging.handlers import DEFAULT_TCP_LOGGING_PORT
+from pathlib import Path
 
 import networkx as nx
 import simplejson
 import tailer
-from flask import Flask, jsonify, request, send_from_directory
+from flask import Flask, jsonify, request, send_from_directory, make_response
 from flask_cors import CORS
 from flask_socketio import SocketIO
 
 from covalent._results_manager import Result
 from covalent._results_manager import results_manager as rm
+from covalent._shared_files.config import get_config
 from covalent._shared_files.util_classes import Status
+from covalent.executor import _executor_manager
 
 WEBHOOK_PATH = "/api/webhook"
 WEBAPP_PATH = "webapp/build"
@@ -65,16 +68,46 @@ def encode_result(obj):
 
 
 def extract_graph_node(node):
-    # TODO placeholder for advanced node transformations Eventually, will pick
-    # instead of omit keys, currently just strip unused fields
+    # doc string
     f = node.get("function")
     if f is not None:
         node["doc"] = node["function"].get_deserialized().__doc__
+
+    # metadata
+    extract_executor_info(node.get("metadata"))
+
+    # prevent JSON encoding
+    node["kwargs"] = encode_dict(node.get("kwargs"))
+
+    # remove unused fields
     node.pop("function")
     node.pop("node_name")
+
     return node
 
 
+def encode_dict(d):
+    """ Avoid JSON encoding when python str() suffices """
+    if not isinstance(d, dict):
+        return d
+    return {k: str(v) for (k, v) in d.items()}
+
+
+def extract_executor_info(metadata):
+    # executor details
+    try:
+        backend = metadata["backend"]
+        executor = _executor_manager.get_executor(name=backend)
+        if executor is not None:
+            # extract attributes
+            metadata["executor"] = encode_dict(executor.__dict__)
+            if not isinstance(backend, str):
+                # if not named, replace with class name
+                metadata["backend"] = f"<{executor.__class__.__name__}>"
+    except (KeyError, AttributeError) as e:
+        pass
+
+
 def extract_graph(result):
     graph = nx.json_graph.node_link_data(result.lattice.transport_graph._graph)
     nodes = list(map(extract_graph_node, graph["nodes"]))
@@ -89,6 +122,7 @@ def fetch_result(dispatch_id):
     results_dir = request.args["resultsDir"]
 
     result = rm.get_result(dispatch_id, results_dir=results_dir)
+    extract_executor_info(result.lattice.metadata)
 
     response = {
         "dispatch_id": result.dispatch_id,
@@ -101,7 +135,7 @@ def fetch_result(dispatch_id):
             "function_string": result.lattice.workflow_function_string,
             "doc": result.lattice.__doc__,
             "name": result.lattice.__name__,
-            "inputs": result.lattice.kwargs,
+            "kwargs": encode_dict(result.lattice.kwargs),
             "metadata": result.lattice.metadata,
         },
         "graph": extract_graph(result),
@@ -113,11 +147,19 @@ def fetch_result(dispatch_id):
     return app.response_class(response, status=200, mimetype="application/json")
 
 
-@app.route("/api/logoutput")
-def fetch_file():
+@app.route("/api/logoutput/<dispatch_id>")
+def fetch_file(dispatch_id):
     path = request.args.get("path")
     n = int(request.args.get("n", 10))
-    lines = tailer.tail(open(path), n)
+
+    if not Path(path).expanduser().is_absolute():
+        path = os.path.join(get_config("dispatcher.results_dir"), dispatch_id, path)
+
+    try:
+        lines = tailer.tail(open(path), n)
+    except Exception as ex:
+        return make_response(jsonify({"message": str(ex)}), 404)
+
     return jsonify({"lines": lines})
 
 
